PyIBL is a Python implementation of a subset of Instance Based Learning Theory
(IBLT) (Cleotilde Gonzalez, Javier F. Lerch and Christian Lebiere (2003),
Instance-based learning in dynamic decision making, Cognitive Science, 27,
591-635. DOI: 10.1016/S0364-0213(03)00031-4). It is made and distributed by
the Dynamic Decision Making Laboratory of Carnegie Mellon University for
making computational cognitive models supporting research in how people make
decisions in dynamic environments.

PyIBL requires Python version 3.8 or later. PyIBL also works in recent
versions of PyPy.

The latest released version of PyIBL may be installed from PyPi with pip:

    pip install pyibl


For further information, including the documentation see the
[online documentation](http://pyibl.ddmlab.com).

PyIBL is copyright 2014-2024 by Carnegie Mellon University. It may be
freely used, and modified, but only for research purposes.
